==> ac3filter_0_53b_src.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by ac3filter.rc
//
#define IDS_TITLE                       1
#define IDS_MAIN                        1
#define IDS_MIXER                       2
#define IDD_AC3FILTER_PROP              106
#define IDD_MAIN                        106
#define IDD_MIXER                       107
#define IDC_EDT_BITRATE                 1003
#define IDC_EDT_SAMPLE_RATE             1004
#define IDC_EDT_CHANNELS                1005
#define IDC_RADIO_1_0                   1006
#define IDC_RADIO_2_0                   1007
#define IDC_RADIO_2_2                   1008
#define IDC_RADIO_3_2                   1009
#define IDC_RADIO_2_1                   1011
#define IDC_RADIO_3_0                   1012
#define IDC_RADIO_3_1                   1013
#define IDC_SLIDER_LFE                  1014
#define IDC_SLIDER_VOICE                1015
#define IDC_SLIDER_SUR                  1016
#define IDC_CHK_DYNRNG                  1022
#define IDC_BSI_DYNRNG_LEVEL            1026
#define IDC_DRC_LEVEL                   1026
#define IDC_CHK_LFELOCK                 1027
#define IDC_CHK_CLOCK                   1028
#define IDC_CHK_SLOCK                   1029
#define IDC_CHK_LFE                     1032
#define IDC_IN_L                        1033
#define IDC_IN_C                        1034
#define IDC_IN_R                        1035
#define IDC_IN_SL                       1036
#define IDC_IN_SR                       1037
#define IDC_IN_LFE                      1038
#define IDC_OUT_L                       1039
#define IDC_OUT_C                       1040
#define IDC_OUT_R                       1041
#define IDC_OUT_SL                      1042
#define IDC_OUT_SR                      1043
#define IDC_OUT_LFE                     1044
#define IDC_CPU                         1045
#define IDC_CPU_LABEL                   1047
#define IDC_EDT_FREQ_HIGH               1048
#define IDC_EDT_FREQ_COUPLING           1049
#define IDC_EDT_ERRORS                  1050
#define IDC_EDT_FRAMES                  1051
#define IDC_SLIDER_GAIN                 1053
#define IDC_SLIDER_MASTER               1054
#define IDC_DRC_POWER                   1056
#define IDC_CHK_NORMALIZE               1057
#define IDC_EDT_L_L                     1058
#define IDC_EDT_L_C                     1059
#define IDC_EDT_L_R                     1060
#define IDC_EDT_L_SL                    1061
#define IDC_EDT_L_SR                    1062
#define IDC_EDT_L_LFE                   1063
#define IDC_EDT_C_L                     1064
#define IDC_EDT_C_C                     1065
#define IDC_EDT_C_R                     1066
#define IDC_EDT_C_SL                    1067
#define IDC_EDT_C_SR                    1068
#define IDC_EDT_C_LFE                   1069
#define IDC_EDT_R_L                     1070
#define IDC_EDT_R_C                     1071
#define IDC_EDT_R_R                     1072
#define IDC_EDT_R_SL                    1073
#define IDC_EDT_R_SR                    1074
#define IDC_EDT_R_LFE                   1075
#define IDC_EDT_SL_L                    1076
#define IDC_EDT_SL_C                    1077
#define IDC_EDT_SL_R                    1078
#define IDC_EDT_SL_SL                   1079
#define IDC_EDT_SL_SR                   1080
#define IDC_EDT_SL_LFE                  1081
#define IDC_EDT_SR_L                    1082
#define IDC_EDT_SR_C                    1083
#define IDC_EDT_SR_R                    1084
#define IDC_EDT_SR_SL                   1085
#define IDC_EDT_SR_SR                   1086
#define IDC_EDT_LFE_C                   1087
#define IDC_EDT_SR_LFE                  1088
#define IDC_EDT_LFE_L                   1089
#define IDC_EDT_LFE_R                   1090
#define IDC_EDT_LFE_SL                  1091
#define IDC_EDT_LFE_SR                  1092
#define IDC_EDT_LFE_LFE                 1093
#define IDC_EDT_MASTER                  1094
#define IDC_EDT_GAIN                    1095
#define IDC_EDT_LFE                     1096
#define IDC_EDT_VOICE                   1097
#define IDC_EDT_SUR                     1098
#define IDC_CHK_NORM_MATRIX             1099
#define IDC_CHK_AUTO_MATRIX             1100
#define IDC_BUTTON1                     1101
#define IDC_BTN_SAVE                    1101
#define IDC_COMBO1                      1102
#define IDC_CMB_MATRIX                  1102
#define IDC_CHK_NORM                    1103
#define IDC_BUTTON2                     1104
#define IDC_BTN_LOAD                    1104
#define IDC_BTN_SET                     1105
#define IDC_RICHEDIT1                   1106
#define IDC_CHK_EXPAND_STEREO           1107
#define IDC_CHK_VOICE_CONTROL           1108

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        101
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1109
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> ac3filter_0_54b_src.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by ac3filter.rc
//
#define IDS_TITLE                       1
#define IDS_MAIN                        1
#define IDS_MIXER                       2
#define IDD_AC3FILTER_PROP              106
#define IDD_MAIN                        106
#define IDD_MIXER                       107
#define IDD_MAIN1                       108
#define IDD_MAIN2                       109
#define IDC_EDT_BITRATE                 1003
#define IDC_EDT_SAMPLE_RATE             1004
#define IDC_EDT_CHANNELS                1005
#define IDC_RADIO_1_0                   1006
#define IDC_RADIO_2_0                   1007
#define IDC_RADIO_2_2                   1008
#define IDC_RADIO_3_2                   1009
#define IDC_RADIO_2_1                   1011
#define IDC_RADIO_3_0                   1012
#define IDC_RADIO_3_1                   1013
#define IDC_SLIDER_LFE                  1014
#define IDC_SLIDER_VOICE                1015
#define IDC_SLIDER_SUR                  1016
#define IDC_CHK_DYNRNG                  1022
#define IDC_BSI_DYNRNG_LEVEL            1026
#define IDC_DRC_LEVEL                   1026
#define IDC_CHK_LFELOCK                 1027
#define IDC_CHK_CLOCK                   1028
#define IDC_CHK_SLOCK                   1029
#define IDC_CHK_LFE                     1032
#define IDC_IN_L                        1033
#define IDC_IN_C                        1034
#define IDC_IN_R                        1035
#define IDC_IN_SL                       1036
#define IDC_IN_SR                       1037
#define IDC_IN_LFE                      1038
#define IDC_OUT_L                       1039
#define IDC_OUT_C                       1040
#define IDC_OUT_R                       1041
#define IDC_OUT_SL                      1042
#define IDC_OUT_SR                      1043
#define IDC_OUT_LFE                     1044
#define IDC_CPU                         1045
#define IDC_CPU_LABEL                   1047
#define IDC_EDT_FREQ_HIGH               1048
#define IDC_EDT_FREQ_COUPLING           1049
#define IDC_EDT_ERRORS                  1050
#define IDC_EDT_FRAMES                  1051
#define IDC_SLIDER_GAIN                 1053
#define IDC_SLIDER_MASTER               1054
#define IDC_DRC_POWER                   1056
#define IDC_CHK_NORMALIZE               1057
#define IDC_EDT_L_L                     1058
#define IDC_EDT_L_C                     1059
#define IDC_EDT_L_R                     1060
#define IDC_EDT_L_SL                    1061
#define IDC_EDT_L_SR                    1062
#define IDC_EDT_L_LFE                   1063
#define IDC_EDT_C_L                     1064
#define IDC_EDT_C_C                     1065
#define IDC_EDT_C_R                     1066
#define IDC_EDT_C_SL                    1067
#define IDC_EDT_C_SR                    1068
#define IDC_EDT_C_LFE                   1069
#define IDC_EDT_R_L                     1070
#define IDC_EDT_R_C                     1071
#define IDC_EDT_R_R                     1072
#define IDC_EDT_R_SL                    1073
#define IDC_EDT_R_SR                    1074
#define IDC_EDT_R_LFE                   1075
#define IDC_EDT_SL_L                    1076
#define IDC_EDT_SL_C                    1077
#define IDC_EDT_SL_R                    1078
#define IDC_EDT_SL_SL                   1079
#define IDC_EDT_SL_SR                   1080
#define IDC_EDT_SL_LFE                  1081
#define IDC_EDT_SR_L                    1082
#define IDC_EDT_SR_C                    1083
#define IDC_EDT_SR_R                    1084
#define IDC_EDT_SR_SL                   1085
#define IDC_EDT_SR_SR                   1086
#define IDC_EDT_LFE_C                   1087
#define IDC_EDT_SR_LFE                  1088
#define IDC_EDT_LFE_L                   1089
#define IDC_EDT_LFE_R                   1090
#define IDC_EDT_LFE_SL                  1091
#define IDC_EDT_LFE_SR                  1092
#define IDC_EDT_LFE_LFE                 1093
#define IDC_EDT_MASTER                  1094
#define IDC_EDT_GAIN                    1095
#define IDC_EDT_LFE                     1096
#define IDC_EDT_VOICE                   1097
#define IDC_EDT_SUR                     1098
#define IDC_CHK_NORM_MATRIX             1099
#define IDC_CHK_AUTO_MATRIX             1100
#define IDC_BUTTON1                     1101
#define IDC_BTN_SAVE                    1101
#define IDC_BTN_TEST                    1101
#define IDC_COMBO1                      1102
#define IDC_CMB_MATRIX                  1102
#define IDC_BTN_TEST1                   1102
#define IDC_CHK_NORM                    1103
#define IDC_BUTTON2                     1104
#define IDC_BTN_LOAD                    1104
#define IDC_BTN_SET                     1105
#define IDC_RICHEDIT1                   1106
#define IDC_CHK_EXPAND_STEREO           1107
#define IDC_CHK_VOICE_CONTROL           1108
#define IDC_CHK_SPDIF                   1109
#define IDC_CMB_PRESET                  1110

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        101
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1111
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
